pitchtools.HarmonicChromaticIntervalSet
=======================================

.. autoclass:: abjad.tools.pitchtools.HarmonicChromaticIntervalSet
   :members:
   :undoc-members:
   :show-inheritance:
